@@ -1,6 +1,6 @@
 /*
  *  Quick Test: CLI for stress testing in competitive programming
- *  Copyright (C) 2021  Luis Miguel Báez
+ *  Copyright (C) 2021 - Luis Miguel Báez
  *  License: MIT (See the LICENSE file in the repository root directory)
  */
 
@@ -13,9 +13,10 @@ use std::sync::Arc;
 use std::sync::Mutex;
 use std::time::Duration;
 
-use crate::runner::types::Compiler;
+use crate::runner::types::Language;
 use std::time::Instant;
 
+#[derive(Debug, Clone)]
 pub struct Cpp {
 
     /// Example: g++
@@ -63,9 +64,9 @@ impl Cpp {
     }
 }
 
-impl Compiler for Cpp {
+impl Language for Cpp {
 
-    fn compile(&self) -> () {
+    fn build(&self) -> () {
         Command::new(self.program)
             .arg(self.standard)
             .args(&self.flags)
@@ -154,4 +155,50 @@ impl Compiler for Cpp {
 
         time 
     }
+}
+
+
+pub mod default {
+    use std::path::PathBuf;
+
+    use super::Cpp;
+    
+    pub fn gnucpp17_default(root: &str, file_name: &str, 
+            binary_file: &str, input_file: &str, output_file: &str,
+            error_file: &str) -> Cpp {
+    
+        let stdin = PathBuf::from(format!("{}/{}", root, input_file));
+        let stdout =  PathBuf::from(format!("{}/{}", root, output_file));
+        let stderr = PathBuf::from(format!("{}/{}", root, error_file));
+
+        Cpp::new(
+            "g++",
+            PathBuf::from(format!("{}/{}", root, file_name)),
+            "-std=c++17",
+            PathBuf::from(format!("{}/{}", root, binary_file)),
+            vec!["-Wall"],
+            vec!["-DLOCAL=1"],
+            Some(stdin),
+            Some(stdout),
+            Some(stderr)
+        )
+    }
+
+    pub fn gnucpp17_set_output(root: &str, file_name: &str, 
+        binary_file: &str, output_file: &str) -> Cpp {
+
+        let stdout =  PathBuf::from(format!("{}/{}", root, output_file));
+
+        Cpp::new(
+            "g++",
+            PathBuf::from(format!("{}/{}", root, file_name)),
+            "-std=c++17",
+            PathBuf::from(format!("{}/{}", root, binary_file)),
+            vec!["-Wall"],
+            vec!["-DLOCAL=1"],
+            None,
+            Some(stdout),
+            None
+        )
+    }
 }
\ No newline at end of file
